==> bonita-server-7.8.4-sources.jar: org/bonitasoft/engine/page/impl/SPageContentHelper.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 */
package org.bonitasoft.engine.page.impl;

import java.io.IOException;
import java.io.StringReader;
import java.nio.charset.StandardCharsets;
import java.util.Map;
import java.util.Properties;

import org.bonitasoft.engine.commons.io.IOUtil;
import org.bonitasoft.engine.page.PageService;
import org.bonitasoft.engine.page.SInvalidPageZipMissingPropertiesException;

/**
 * @author Laurent Leseigneur
 */
public class SPageContentHelper {

    public Properties loadPageProperties(final byte[] zipContent) throws IOException, SInvalidPageZipMissingPropertiesException {
        final Map<String, byte[]> content = IOUtil.unzip(zipContent);
        return loadPageProperties(content);
    }

    public Properties loadPageProperties(final Map<String, byte[]> content) throws SInvalidPageZipMissingPropertiesException, IOException {
        final byte[] pagePropertiesContent = content.get(PageService.PROPERTIES_FILE_NAME);
        if (pagePropertiesContent == null) {
            throw new SInvalidPageZipMissingPropertiesException();
        }

        final Properties pageProperties = new Properties();
        try (StringReader reader = new StringReader(new String(pagePropertiesContent, StandardCharsets.UTF_8))) {
            pageProperties.load(reader);
        }
        return pageProperties;
    }

}

==> bonita-server-7.10.6-sources.jar: org/bonitasoft/engine/page/impl/SPageContentHelper.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.page.impl;

import java.io.IOException;
import java.io.StringReader;
import java.nio.charset.StandardCharsets;
import java.util.Map;
import java.util.Properties;

import org.bonitasoft.engine.commons.io.IOUtil;
import org.bonitasoft.engine.page.PageService;
import org.bonitasoft.engine.page.SInvalidPageZipMissingPropertiesException;

/**
 * @author Laurent Leseigneur
 */
public class SPageContentHelper {

    public Properties loadPageProperties(final byte[] zipContent)
            throws IOException, SInvalidPageZipMissingPropertiesException {
        final Map<String, byte[]> content = IOUtil.unzip(zipContent);
        return loadPageProperties(content);
    }

    public Properties loadPageProperties(final Map<String, byte[]> content)
            throws SInvalidPageZipMissingPropertiesException, IOException {
        final byte[] pagePropertiesContent = content.get(PageService.PROPERTIES_FILE_NAME);
        if (pagePropertiesContent == null) {
            throw new SInvalidPageZipMissingPropertiesException();
        }

        final Properties pageProperties = new Properties();
        try (StringReader reader = new StringReader(new String(pagePropertiesContent, StandardCharsets.UTF_8))) {
            pageProperties.load(reader);
        }
        return pageProperties;
    }

}
